@@ -1,26 +1,15 @@
 /*
     knewstuff3/ui/knewstuffbutton.cpp.
-    Copyright (c) 2004 Aaron J. Seigo <aseigo@kde.org>
+    SPDX-FileCopyrightText: 2004 Aaron J. Seigo <aseigo@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "button.h"
 
-#include <klocalizedstring.h>
-#include <kauthorized.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KAuthorized>
+#include <KMessageBox>
 #include "downloaddialog.h"
 #include "ui/widgetquestionlistener.h"
 
@@ -87,13 +76,13 @@ void Button::showDialog()
         KMessageBox::information(this, QStringLiteral("Get Hot New Stuff is disabled by the administrator"), QStringLiteral("Get Hot New Stuff disabled"));
         return;
     }
-    emit aboutToShowDialog();
+    Q_EMIT aboutToShowDialog();
 
     QPointer<DownloadDialog> dialog = new DownloadDialog(d->configFile, this);
     dialog->exec();
 
     if (dialog)
-        emit dialogFinished(dialog->changedEntries());
+        Q_EMIT dialogFinished(dialog->changedEntries());
 
     delete dialog;
 }
