@@ -1,21 +1,10 @@
 /*
     This file is part of KNewStuff2.
-    Copyright (c) 2002 Cornelius Schumacher <schumacher@kde.org>
-    Copyright (c) 2003 - 2007 Josef Spillner <spillner@kde.org>
-    Copyright (C) 2009 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-FileCopyrightText: 2002 Cornelius Schumacher <schumacher@kde.org>
+    SPDX-FileCopyrightText: 2003-2007 Josef Spillner <spillner@kde.org>
+    SPDX-FileCopyrightText: 2009 Frederik Gladhorn <gladhorn@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "entryinternal.h"
@@ -550,7 +539,7 @@ bool KNSCore::EntryInternal::setEntryXML(QXmlStreamReader& reader)
             if (reader.tokenType() == QXmlStreamReader::Characters)
                 readNextSkipComments(&reader);
         }
-        Q_ASSERT_X(reader.tokenType() == QXmlStreamReader::EndElement, Q_FUNC_INFO, QStringLiteral("token name was %1 and the type was %2").arg(reader.name().toString()).arg(reader.tokenString()).toLocal8Bit().data());
+        Q_ASSERT_X(reader.tokenType() == QXmlStreamReader::EndElement, Q_FUNC_INFO, QStringLiteral("token name was %1 and the type was %2").arg(reader.name().toString(), reader.tokenString()).toLocal8Bit().data());
     }
 
     // Validation
@@ -629,6 +618,8 @@ bool KNSCore::EntryInternal::setEntryXML(const QDomElement &xmldata)
         } else if (e.tagName() == QLatin1String("checksum")) {
             d->mChecksum = e.text();
         } else if (e.tagName() == QLatin1String("installedfile")) {
+            // TODO KF6 Add a "installeddirectory" entry to avoid
+            // all the issues with the "/*" notation which is currently used as a workaround
             d->mInstalledFiles.append(e.text());
         } else if (e.tagName() == QLatin1String("id")) {
             d->mUniqueId = e.text();
